@@ -9,15 +9,20 @@
 #ifndef __kparts_browserextension_h__
 #define __kparts_browserextension_h__
 
-#include <kparts/readonlypart.h>
-#include <kparts/openurlarguments.h>
 #include <kparts/browserarguments.h>
+#include <kparts/openurlarguments.h>
+#include <kparts/readonlypart.h>
 #include <kparts/windowargs.h>
 
+#include <memory>
+
+#include <QAction>
 #include <qplatformdefs.h> //mode_t
 
-template <class Key, class T> class QMap;
-template<typename T> class QList;
+template<class Key, class T>
+class QMap;
+template<typename T>
+class QList;
 
 class KFileItem;
 class KFileItemList;
@@ -26,7 +31,6 @@ class QPoint;
 
 namespace KParts
 {
-
 class BrowserInterface;
 
 /**
@@ -83,7 +87,7 @@ class BrowserInterface;
  * @li @p reparseConfiguration : Re-read configuration and apply it.
  * @li @p disableScrolling: no scrollbars
  */
-class KPARTS_EXPORT BrowserExtension : public QObject
+class KPARTS_EXPORT BrowserExtension : public QObject // TODO KF6, rename class and header to NavigationExtension. See https://phabricator.kde.org/T12224
 {
     Q_OBJECT
     Q_PROPERTY(bool urlDropHandling READ isURLDropHandlingEnabled WRITE setURLDropHandlingEnabled)
@@ -104,19 +108,20 @@ public:
     enum PopupFlag {
         DefaultPopupItems = 0x0000, /**< default value, no additional menu item */
 #if KPARTS_ENABLE_DEPRECATED_SINCE(5, 27)
-        ShowNavigationItems = 0x0001, /**< @deprecated since 5.27, no effect anymore */
-        ShowUp = 0x0002, /**< @deprecated since 5.27, no effect anymore */
-        ShowReload = 0x0004, /**< @deprecated since 5.27, no effect anymore */
+        ShowNavigationItems KPARTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 27, "No effect anymore") =
+            0x0001, /**< @deprecated since 5.27, no effect anymore */
+        ShowUp KPARTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 27, "No effect anymore") = 0x0002, /**< @deprecated since 5.27, no effect anymore */
+        ShowReload KPARTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 27, "No effect anymore") = 0x0004, /**< @deprecated since 5.27, no effect anymore */
 #endif
         ShowBookmark = 0x0008, /**< show "add to bookmarks" (usually not done on the local filesystem) */
         ShowCreateDirectory = 0x0010, /**<  show "create directory" (usually only done on the background of the view, or
-       *                      in hierarchical views like directory trees, where the new dir would be visible) */
+                                       *                      in hierarchical views like directory trees, where the new dir would be visible) */
         ShowTextSelectionItems = 0x0020, /**< set when selecting text, for a popup that only contains text-related items. */
         NoDeletion = 0x0040, /**< deletion, trashing and renaming not allowed (e.g. parent dir not writeable).
-       *            (this is only needed if the protocol itself supports deletion, unlike e.g. HTTP) */
+                              *            (this is only needed if the protocol itself supports deletion, unlike e.g. HTTP) */
         IsLink = 0x0080, /**< show "Bookmark This Link" and other link-related actions (linkactions merging group) */
         ShowUrlOperations = 0x0100, /**< show copy, paste, as well as cut if NoDeletion is not set. */
-        ShowProperties = 0x200   /**< show "Properties" action (usually done by directory views) */
+        ShowProperties = 0x200, /**< show "Properties" action (usually done by directory views) */
     };
 
     /**
@@ -208,6 +213,8 @@ public:
     QString actionText(const char *name) const;
 
     typedef QMap<QByteArray, QByteArray> ActionSlotMap;
+
+#if KPARTS_ENABLE_DEPRECATED_SINCE(5, 83)
     /**
      * Returns a map containing the action names as keys and corresponding
      * SLOT()'ified method names as data entries.
@@ -236,13 +243,15 @@ public:
      *
      * (where "mapIterator" is your ActionSlotMap iterator)
      */
+    KPARTS_DEPRECATED_VERSION(5, 83, "Use actionSlotMapPtr instead")
     static ActionSlotMap actionSlotMap();
+#endif
 
     /**
      * @return a pointer to the static action-slot map. Preferred method to get it.
      * The map is created if it doesn't exist yet
      */
-    static ActionSlotMap *actionSlotMapPtr();
+    static ActionSlotMap *actionSlotMapPtr(); // TODO KF6 Rename to actionSlotMap
 
     /**
      * Queries @p obj for a child object which inherits from this
@@ -261,7 +270,7 @@ public:
      * "linkactions" for actions related to hyperlinks,
      * "partactions" for any other actions provided by the part
      */
-    typedef QMap<QString, QList<QAction *> > ActionGroupMap;
+    typedef QMap<QString, QList<QAction *>> ActionGroupMap;
 
 Q_SIGNALS:
     /**
@@ -295,9 +304,7 @@ Q_SIGNALS:
      * being destroyed. Parts should never use this signal, hosts should only connect
      * to this signal.
      */
-    void openUrlRequestDelayed(const QUrl &url,
-                               const KParts::OpenUrlArguments &arguments,
-                               const KParts::BrowserArguments &browserArguments);
+    void openUrlRequestDelayed(const QUrl &url, const KParts::OpenUrlArguments &arguments, const KParts::BrowserArguments &browserArguments);
 
     /**
      * Tells the hosting browser that the part opened a new URL (which can be
@@ -344,7 +351,7 @@ Q_SIGNALS:
                          const KParts::OpenUrlArguments &arguments = KParts::OpenUrlArguments(),
                          const KParts::BrowserArguments &browserArguments = KParts::BrowserArguments(),
                          const KParts::WindowArgs &windowArgs = KParts::WindowArgs(),
-                         KParts::ReadOnlyPart **part = nullptr);  // TODO consider moving to BrowserHostExtension?
+                         KParts::ReadOnlyPart **part = nullptr); // TODO consider moving to BrowserHostExtension?
 
     /**
      * Since the part emits the jobid in the started() signal,
@@ -372,7 +379,8 @@ Q_SIGNALS:
      * @param flags enables/disables certain builtin actions in the popupmenu
      * @param actionGroups named groups of actions which should be inserted into the popup, see ActionGroupMap
      */
-    void popupMenu(const QPoint &global, const KFileItemList &items,
+    void popupMenu(const QPoint &global,
+                   const KFileItemList &items,
                    const KParts::OpenUrlArguments &args = KParts::OpenUrlArguments(),
                    const KParts::BrowserArguments &browserArguments = KParts::BrowserArguments(),
                    KParts::BrowserExtension::PopupFlags flags = KParts::BrowserExtension::DefaultPopupItems,
@@ -392,7 +400,8 @@ Q_SIGNALS:
      * @param flags enables/disables certain builtin actions in the popupmenu
      * @param actionGroups named groups of actions which should be inserted into the popup, see ActionGroupMap
      */
-    void popupMenu(const QPoint &global, const QUrl &url,
+    void popupMenu(const QPoint &global,
+                   const QUrl &url,
                    mode_t mode = static_cast<mode_t>(-1),
                    const KParts::OpenUrlArguments &args = KParts::OpenUrlArguments(),
                    const KParts::BrowserArguments &browserArguments = KParts::BrowserArguments(),
@@ -468,14 +477,11 @@ public:
     typedef QMap<QByteArray, int> ActionNumberMap;
 
 private:
-    class BrowserExtensionPrivate;
-    BrowserExtensionPrivate *const d;
+    std::unique_ptr<class BrowserExtensionPrivate> const d;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(BrowserExtension::PopupFlags)
 
 }
 
-
 #endif
-
