@@ -13,7 +13,6 @@
 
 using namespace KParts;
 
-
 PartBase::PartBase()
     : d_ptr(new PartBasePrivate(this))
 {
@@ -24,10 +23,7 @@ PartBase::PartBase(PartBasePrivate &dd)
 {
 }
 
-PartBase::~PartBase()
-{
-    delete d_ptr;
-}
+PartBase::~PartBase() = default;
 
 void PartBase::setPartObject(QObject *obj)
 {
@@ -43,44 +39,58 @@ QObject *PartBase::partObject() const
     return d->m_obj;
 }
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 77)
 KAboutData PartBase::componentData() const
 {
     Q_D(const PartBase);
-    return d->m_componentData;
-}
 
+    return d->componentData();
+}
+#endif
+
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 77)
 void PartBase::setComponentData(const KAboutData &componentData)
 {
     setComponentData(componentData, true);
 }
+#endif
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 77)
 void PartBase::setComponentData(const KAboutData &pluginData, bool bLoadPlugins)
 {
     Q_D(PartBase);
 
-    d->m_componentData = pluginData;
+    d->setComponentData(pluginData);
 
     // backward-compatible registration, usage deprecated
 #if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 76)
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
     KAboutData::registerPluginData(pluginData);
-QT_WARNING_POP
+    QT_WARNING_POP
 #endif
 
     KXMLGUIClient::setComponentName(pluginData.componentName(), pluginData.displayName());
     if (bLoadPlugins) {
-        loadPlugins(d->m_obj, this, pluginData);
+        loadPlugins(d->m_obj, this, pluginData.componentName());
     }
 }
+#endif
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 77)
 void PartBase::loadPlugins(QObject *parent, KXMLGUIClient *parentGUIClient, const KAboutData &instance)
+{
+    loadPlugins(parent, parentGUIClient, instance.componentName());
+}
+#endif
+
+void PartBase::loadPlugins(QObject *parent, KXMLGUIClient *parentGuiClient, const QString &parentInstanceName)
 {
     Q_D(PartBase);
 
     if (d->m_pluginLoadingMode != DoNotLoadPlugins) {
-        Plugin::loadPlugins(parent, parentGUIClient, instance.componentName(), d->m_pluginLoadingMode == LoadPlugins, d->m_pluginInterfaceVersion);
+        Plugin::loadPlugins(parent, parentGuiClient, parentInstanceName, d->m_pluginLoadingMode == LoadPlugins, d->m_pluginInterfaceVersion);
     }
 }
 
@@ -97,4 +107,3 @@ void KParts::PartBase::setPluginInterfaceVersion(int version)
 
     d->m_pluginInterfaceVersion = version;
 }
-
